%%
%% This is file `mTTenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cmtt.dtx  (with options: `def')
%% 
%% IMPORTANT NOTICE
%%
%% mdwlist package -- various list-related things
%% Copyright (c) 1996 Mark Wooding
%%
%% This program is free software; you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation; either version 2 of the License, or
%% (at your option) any later version.
%%
%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%%
\ProvidesFile{mTTcmtt.def}
         [1996/05/25 1.1 Handing of the cmtt font]
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\def\cmtt@accent#1#2{{%
  \let\@old@font\font@name%
  \ifcmtt@dcfonts%
    \fontencoding{T1}\selectfont%
  \else%
    \usefont{OT1}{cmr}{bx}{n}%
  \fi%
  #1{\@old@font#2}%
}}
\DeclareTextCommand{\H}{mTT}{\cmtt@accent\H}
\DeclareTextCommand{\.}{mTT}{\cmtt@accent\.}
\DeclareTextSymbol{\textbackslash}{mTT}{92}
\DeclareTextSymbol{\textbar}{mTT}{124}
\DeclareTextSymbol{\textbraceleft}{mTT}{123}
\DeclareTextSymbol{\textbraceright}{mTT}{125}
\DeclareTextSymbol{\textless}{mTT}{60}
\DeclareTextSymbol{\textgreater}{mTT}{62}
\DeclareTextSymbol{\textunderscore}{mTT}{95}
\DeclareTextSymbol{\textvisiblespace}{mTT}{32}
\DeclareTextCommand{\textellipsis}{mTT}{...}
\DeclareTextSymbol{\textquotedbl}{mTT}{34}
\DeclareTextSymbol{\textquotesingl}{mTT}{13}
\endinput
%%
%% End of file `mTTenc.def'.
