% latin3jk.def
%
% (c) Copyright 1995, 1996, 2000, 2003 J"org Knappen.
% Licence GNU licence Version 2
% see after \endinput for further information
%
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesFile{latin3jk.def}[2003/10/02 latin-3 input encoding file v1.3 (JKn)]
%%%\RequirePackage{textcomp}    % text companion symbols (tc fonts)
%%%\RequirePackage[T4]{fontenc} % fc fonts needed for maltese
\DeclareInputText{"0A0}{~}
\DeclareInputText{"0A1}{\B H} % Maltese barred H
\DeclareInputText{"0A2}{\u{}}
\DeclareInputText{"0A3}{\textsterling}
\DeclareInputText{"0A4}{\textcurrency}
%\DeclareInputText{"0A5}{\notdef}
\DeclareInputText{"0A6}{\^H}
\DeclareInputText{"0A7}{\S}
\DeclareInputText{"0A8}{\"{}}
\DeclareInputText{"0A9}{\.I}
\DeclareInputText{"0AA}{\c S}
\DeclareInputText{"0AB}{\u G}
\DeclareInputText{"0AC}{\^J}
\DeclareInputText{"0AD}{\@dischyph}
%\DeclareInputText{"0AE}{\notdef}
\DeclareInputText{"0AF}{\.Z}
%
\DeclareInputText{"0B0}{\textdegree}
\DeclareInputText{"0B1}{\B h} % Maltese barred h
\DeclareInputText{"0B2}{\texttwosuperior}
\DeclareInputText{"0B3}{\textthreesuperior}
\DeclareInputText{"0B4}{\@tabacckludge'{}}
\DeclareInputText{"0B5}{\textmu}
\DeclareInputText{"0B6}{h\llap{\^{}}} % \^h would be too tall
\DeclareInputText{"0B7}{\textperiodcentered}
\DeclareInputText{"0B8}{\c{\ }}
\DeclareInputText{"0B9}{\i}
\DeclareInputText{"0BA}{\c s}
\DeclareInputText{"0BB}{\u g}
\DeclareInputText{"0BC}{\^\j}
\DeclareInputText{"0BD}{\textonehalf}
%\DeclareInputText{"0BE}{\notdef}
\DeclareInputText{"0BF}{\.z}
%
\DeclareInputText{"0C0}{\@tabacckludge`A}
\DeclareInputText{"0C1}{\@tabacckludge'A}
\DeclareInputText{"0C2}{\^A}
%\DeclareInputText{"0C3}{\notdef}
\DeclareInputText{"0C4}{\"A}
\DeclareInputText{"0C5}{\.C}
\DeclareInputText{"0C6}{\^C}
\DeclareInputText{"0C7}{\c C}
\DeclareInputText{"0C8}{\@tabacckludge`E}
\DeclareInputText{"0C9}{\@tabacckludge'E}
\DeclareInputText{"0CA}{\^E}
\DeclareInputText{"0CB}{\"E}
\DeclareInputText{"0CC}{\@tabacckludge`I}
\DeclareInputText{"0CD}{\@tabacckludge'I}
\DeclareInputText{"0CE}{\^I}
\DeclareInputText{"0CF}{\"I}
%
%\DeclareInputText{"0D0}{\notdef}
\DeclareInputText{"0D1}{\~N}
\DeclareInputText{"0D2}{\@tabacckludge`O}
\DeclareInputText{"0D3}{\@tabacckludge'O}
\DeclareInputText{"0D4}{\^O}
\DeclareInputText{"0D5}{\.G}
\DeclareInputText{"0D6}{\"O}
\DeclareInputText{"0D7}{\texttimes}
\DeclareInputText{"0D8}{\^G}
\DeclareInputText{"0D9}{\@tabacckludge`U}
\DeclareInputText{"0DA}{\@tabacckludge'U}
\DeclareInputText{"0DB}{\^U}
\DeclareInputText{"0DC}{\"U}
\DeclareInputText{"0DD}{\u U}
\DeclareInputText{"0DE}{\^S}
\DeclareInputText{"0DF}{\ss}
%
\DeclareInputText{"0E0}{\@tabacckludge`a}
\DeclareInputText{"0E1}{\@tabacckludge'a}
\DeclareInputText{"0E2}{\^a}
%\DeclareInputText{"0E3}{\notdef}
\DeclareInputText{"0E4}{\"a}
\DeclareInputText{"0E5}{\.c}
\DeclareInputText{"0E6}{\^c}
\DeclareInputText{"0E7}{\c c}
\DeclareInputText{"0E8}{\@tabacckludge`e}
\DeclareInputText{"0E9}{\@tabacckludge'e}
\DeclareInputText{"0EA}{\^e}
\DeclareInputText{"0EB}{\"e}
\DeclareInputText{"0EC}{\@tabacckludge`\i}
\DeclareInputText{"0ED}{\@tabacckludge'\i}
\DeclareInputText{"0EE}{\^\i}
\DeclareInputText{"0EF}{\"\i}
%
%\DeclareInputText{"0F0}{\notdef}
\DeclareInputText{"0F1}{\~n}
\DeclareInputText{"0F2}{\@tabacckludge`o}
\DeclareInputText{"0F3}{\@tabacckludge'o}
\DeclareInputText{"0F4}{\^o}
\DeclareInputText{"0F5}{\.g}
\DeclareInputText{"0F6}{\"o}
\DeclareInputText{"0F7}{\textdiv}
\DeclareInputText{"0F8}{\^g}
\DeclareInputText{"0F9}{\@tabacckludge`u}
\DeclareInputText{"0FA}{\@tabacckludge'u}
\DeclareInputText{"0FB}{\^u}
\DeclareInputText{"0FC}{\"u}
\DeclareInputText{"0FD}{\u u}
\DeclareInputText{"0FE}{\^ s}
\DeclareInputText{"0FF}{\.{}}
\endinput
%Usage:
% \documentclass{...}
% \usepackage{textcomp} % required!
% \usepackage[T4]{fontenc} % required for maltese barred H only.
% ...
% \begin{document}
%
% The set of graphic characters used for general purpose applications in
% typical office environments in the following languages:
% Afrikaans, Catalan, English, Esperanto, French, Gallician, German,
% Italian, Maltese, and Turkish.
%
% I decided to make \emph{all} characters text, even times and divide, in
% order to make it work in verbatim style environments. A number of control
% sequences refers to the textcomp package of Sebastian Rahtz. The text
% companion fonts are needed to display those characters.
%
% \B H and \B h  (maltese barred H) need the african computer modern fonts
% (fc fonts) and the t4enc.def file for the fontenc package.
%
% \textcurrency, \textdegree, \texttwosuperior, \textthreesuperior, 
% \textmu, \textonehalf, \texttimes, and \textdiv are defined in 
% the textcomp package using the text companion font (TS1 coding).
%
% Changes:
%
% Version 1.3
% Get rid of old definitions requiring tccompat.sty
% Commented out all undefinied characters in the Latin-3 charset
%
% Author:
%
% J\"org Knappen, Dieselstra{\ss}e 13, D-66123 Saarbr\"ucken, Allemagne. 
% Author of the Book: Schnell ans Ziel mit LaTeX2e, Oldenbourg-Verlag
% M\"unchen, 1997, ISBN 3-486-24199-0. 2nd, extended printint 2003.
%
%% End of file latin3jk.def
