%%
%% This is file `ppvtex.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% pdfpages.dtx  (with options: `ppvtexdef')
%% 
%% This file is part of the pdfpages package.
%% 
%% Copyright (C) 2001-2025 Andreas MATTHIAS
%%
%% This work may be distributed and/or modified under the conditions
%% of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   <http://www.latex-project.org/lppl.txt>.
%%
%% This work has the LPPL maintenance status `maintained'.
%%
%% The Current Maintainer of this work is
%%   Andreas Matthias <andreas.matthias@gmail.com>.
%%
%% Please send error reports and suggestions for improvements to
%%   Andreas MATTHIAS <andreas.matthias@gmail.com>.
%%
\def\AM@git@tag{v0.6g}
\def\AM@git@date{2025/07/23}
\def\AM@git@hash{b55a30b6b0}
\ProvidesFile{ppvtex.def}
   [\AM@git@date\space\AM@git@tag\space
    Pdfpages driver for VTeX (AM)]
\begingroup
\@ifundefined{ver@vtex.def}{%
  \PackageError{pdfpages}
         {The graphics package was loaded with driver\MessageBreak
          `\Gin@driver', which cannot be used with VTeX}
         {Check the driver option of the graphics package.}%
  \global\let\AM@endinput\relax
  \aftergroup\endinput}{}
\endgroup
\ifnum\VTeXversion<822
  \PackageError{pdfpages}
         {Package pdfpages requires at least\MessageBreak
          VTeX version 8.22}
         {Update your VTeX distribution.}%
  \let\AM@endinput\relax
\fi
\AM@ifdriverlater{vtex}{2003/06/16}{}{%
  \PackageError{pdfpages}{%
       Your version of `vtex.def' is too old}
       {Please, update your `vtex.def'!}%
  \let\AM@endinput\relax
  \expandafter\endinput
}
\def\AM@getpagecount{%
  \getpagecount\count@ \AM@currentdocname\relax
  \edef\AM@pagecount{\the\count@}%
}
\def\AM@getpagedimen{%
  \AM@pagewidth=\mediawidth
  \AM@pageheight=\mediaheight
}
\def\AM@setpagedimen{%
  \mediawidth\AM@pagewidth
  \mediaheight\AM@pageheight
}
\let\AM@pagesize@boogie\relax
\def\AM@setRotate{\special{pS:
    [{ThisPage}\string<\string</Rotate 90\string>\string>%]
    /PUT pdfmark}%
}
\def\AM@resetRotate{}
\def\AM@fitpaper@special{%
  \immediate\xspecial{option updatemediasizes="on"}}
\def\AM@findfile#1{%
  \AM@findfile@i{#1}{pdf}%
  \ifx\AM@currentdocname\relax
    \AM@findfile@i{#1}{ps}%
  \fi
  \AM@findfile@ii{#1}%
}
\let\AM@IfFileExists\IfFileExists
\def\AM@linktodoc@special@begin{%
  \special{!aref <\ifAM@newwindow n\fi
           f=\AM@linkfilename>!\AM@linktodoc@page;
           a=</Border [0 0 0]>}%
}
\def\AM@linktodoc@special@end{%
  \special{!endaref}%
}
\def\AM@survey@special@begin{%
  \special{!aref pdfpages.\AM@linktodoc@page@m@ne;
    a=</Border [0 0 0]>}%
}
\def\AM@survey@special@end{%
  \special{!endaref}%
}
\def\AM@thread@special@begin{%
  \special{!thread <\threadinfodict> \AM@threadname}%
}
\def\AM@thread@special@end{\special{!endthread}}
\def\AM@reset@view{%
  \def\AM@view{}%
  \def\AM@view@xpos{0}%
  \def\AM@view@ypos{}}
\def\AM@dest@special{\special{!aname \AM@linkname.\AM@page}}
\def\AM@anchor@special{\special{!aname pdfpages.\the\count1}}
\def\AM@convert@dest#1{}
\let\AM@disable@includegraphics\relax
\endinput
%%
%% End of file `ppvtex.def'.
