%%
%% This is file `hyperref-colorschemes.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref-generic.dtx  (with options: `colorscheme')
%% 
%% Copyright (C) 2019-2025 The LaTeX Project
%% 
%% It may be distributed and/or modified under the conditions of
%% the LaTeX Project Public License (LPPL), either version 1.3c of
%% this license or (at your option) any later version.  The latest
%% version of this license is in the file:
%% 
%%    https://www.latex-project.org/lppl.txt
%% 
%% This file is part of the "LaTeX PDF management bundle" (The Work in LPPL)
%% and all files in that bundle must be distributed together.
%% 
%% File: hyperref-generic.dtx


\prop_const_from_keyval:cn { c__hyp_colorscheme_primary-colors_prop }
 {
   linkcolor       = [rgb]{1,0,0}, %red
   filecolor       = [rgb]{0,1,1}, %cyan
   urlcolor        = [rgb]{1,0,1}, %magenta
   menucolor       = [rgb]{1, 0, 0}, %red
   runcolor        = [rgb]{0,1,1}, %cyan
 %-------------
   linkbordercolor = [rgb]{1, 0 ,0 },
   filebordercolor = [rgb]{0, .5, .5},
   urlbordercolor  = [rgb]{0, 1, 1},
   menubordercolor = [rgb]{1, 0, 0},
   runbordercolor  = [rgb]{0, .7, .7}
 }

\prop_const_from_keyval:Nn \c__hyp_colorscheme_daleif_prop
 {
   linkcolor       = [rgb]{0,0.2,0.6},
   filecolor       = [rgb]{0.8,0,0.8},
   urlcolor        = [rgb]{0.8,0,0.8},
   menucolor       = [rgb]{0,0.2,0.6},
   runcolor        = [rgb]{0.8,0,0.8},
 %-------------     %--------
   linkbordercolor = [rgb]{0,0.2,0.6},
   filebordercolor = [rgb]{0.8,0,0.8},
   urlbordercolor  = [rgb]{0.8,0,0.8},
   menubordercolor = [rgb]{0,0.2,0.6},
   runbordercolor  = [rgb]{0.8,0,0.8}
 }

\prop_const_from_keyval:Nn \c__hyp_colorscheme_julian_prop
 { %two colors: intern/extern
   linkcolor       = [rgb]{0.79216, 0, 0.12549},
   filecolor       = [rgb]{0.01961, 0.44314, 0.6902},
   urlcolor        = [rgb]{0.01961, 0.44314, 0.6902},
   menucolor       = [rgb]{0.79216, 0, 0.12549 },
   runcolor        = [rgb]{0.01961, 0.44314, 0.6902 },
 %-------------     %--------
   linkbordercolor = [rgb]{0.79216, 0, 0.12549},
   filebordercolor = [rgb]{0.01961, 0.44314, 0.6902},
   urlbordercolor  = [rgb]{0.01961, 0.44314, 0.6902},
   menubordercolor = [rgb]{0.79216, 0, 0.12549 },
   runbordercolor  = [rgb]{0.01961, 0.44314, 0.6902 }
 }

\prop_const_from_keyval:Nn \c__hyp_colorscheme_tivv_prop
 { %all darkgray
   linkcolor       = [rgb]{0.4 ,0.4 ,0.4 },
   filecolor       = [rgb]{0.4 ,0.4 ,0.4 },
   urlcolor        = [rgb]{0.4 ,0.4 ,0.4 },
   menucolor       = [rgb]{0.4 ,0.4 ,0.4 },
   runcolor        = [rgb]{0.4 ,0.4 ,0.4 },
 %-------------     %--------
   linkbordercolor = [rgb]{0.4 ,0.4 ,0.4 },
   filebordercolor = [rgb]{0.4 ,0.4 ,0.4 },
   urlbordercolor  = [rgb]{0.4 ,0.4 ,0.4 },
   menubordercolor = [rgb]{0.4 ,0.4 ,0.4 },
   runbordercolor  = [rgb]{0.4 ,0.4 ,0.4 }
 }

\prop_const_from_keyval:Nn \c__hyp_colorscheme_szabolcsA_prop
 { %dvipsnam.def
   linkcolor       = [rgb]{0.06, 0.46, 1}, %NavyBlue
   filecolor       = [rgb]{1, 0, 0}, %Red
   urlcolor        = [rgb]{0.06, 0.46, 1}, %NavyBlue
   menucolor       = [rgb]{1, 0, 0}, %Red
   runcolor        = [rgb]{1, 0, 0}, %Red
 %-------------     %------------------
   linkbordercolor = [rgb]{0.06, 0.46, 1}, %NavyBlue
   filebordercolor = [rgb]{1, 0, 0}, %Red
   urlbordercolor  = [rgb]{0.06, 0.46, 1}, %NavyBlue
   menubordercolor = [rgb]{1, 0, 0}, %Red
   runbordercolor  = [rgb]{1, 0, 0} %Red
 }

\prop_const_from_keyval:Nn \c__hyp_colorscheme_szabolcsB_prop
 { %dvipsnam.def
   linkcolor       = [rgb]{0.72, 0, 0}, %BrickRed
   filecolor       = [rgb]{0, 1, 0},    %Green
   urlcolor        = [rgb]{0.64, 0.08, 0.98}, %Mulberry
   menucolor       = [rgb]{0.06, 0.46, 1}, %NavyBlue
   runcolor        = [rgb]{0.64, 0.08, 0.98}, %Mulberry
 %-------------     %------------------
   linkbordercolor = [rgb]{0.72, 0, 0}, %BrickRed
   filebordercolor = [rgb]{0, 1, 0},    %Green
   urlbordercolor  = [rgb]{0.64, 0.08, 0.98}, %Mulberry
   menubordercolor = [rgb]{0.06, 0.46, 1}, %NavyBlue
   runbordercolor  = [rgb]{0.64, 0.08, 0.98} %Mulberry
 }

\prop_const_from_keyval:Nn \c__hyp_colorscheme_phelype_prop
 {
   linkcolor       = [rgb]{0.50196, 0, 0.02353},
   filecolor       = [rgb]{0.07451, 0.09412, 0.46667},
   urlcolor        = [rgb]{0.54118, 0, 0.52941},
   menucolor       = [rgb]{0.44706, 0.45882, 0},
   runcolor        = [rgb]{0.07451, 0.46667, 0.46275},
 %-------------      %-------------
   linkbordercolor = [rgb]{0.701176, 0.4, 0.414118},
   filebordercolor = [rgb]{0.444706, 0.456472, 0.680002},
   urlbordercolor  = [rgb]{0.724708, 0.4, 0.717646},
   menubordercolor = [rgb]{0.668236, 0.675292, 0.4},
   runbordercolor  = [rgb]{0.444706, 0.680002, 0.67765}
 }

\prop_const_from_keyval:Nn \c__hyp_colorscheme_henryford_prop
 {
   linkcolor       = [rgb]{0,0,0},
   filecolor       = [rgb]{0,0,0},
   urlcolor        = [rgb]{0,0,0},
   menucolor       = [rgb]{0,0,0},
   runcolor        = [rgb]{0,0,0},
 %-------------     %--------
   linkbordercolor = [rgb]{0,0,0},
   filebordercolor = [rgb]{0,0,0},
   urlbordercolor  = [rgb]{0,0,0},
   menubordercolor = [rgb]{0,0,0},
   runbordercolor  = [rgb]{0,0,0}
 }
%% 
%%
%% End of file `hyperref-colorschemes.def'.
