%%
%% This is file `ppdvips.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% pdfpages.dtx  (with options: `ppdvipsdef')
%% 
%% This file is part of the pdfpages package.
%% 
%% Copyright (C) 2001-2025 Andreas MATTHIAS
%%
%% This work may be distributed and/or modified under the conditions
%% of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   <http://www.latex-project.org/lppl.txt>.
%%
%% This work has the LPPL maintenance status `maintained'.
%%
%% The Current Maintainer of this work is
%%   Andreas Matthias <andreas.matthias@gmail.com>.
%%
%% Please send error reports and suggestions for improvements to
%%   Andreas MATTHIAS <andreas.matthias@gmail.com>.
%%
\def\AM@git@tag{v0.6g}
\def\AM@git@date{2025/07/23}
\def\AM@git@hash{b55a30b6b0}
\ProvidesFile{ppdvips.def}
   [\AM@git@date\space\AM@git@tag\space
    Pdfpages driver for dvips (AM)]
\def\AM@notsupported#1{%
  \PackageWarning{pdfpages}{#1 not supported by driver dvips}}
\def\AM@getpagecount{%
  \ifx\AM@pagecount\AM@undefined
    \AM@notsupported{Page selections}
    \def\AM@pagecount{1}%
    \gdef\AM@getpagecount{%
      \def\AM@pagecount{1}%
    }%
  \fi
}
\def\AM@getpagedimen{%
  \AM@pagewidth=\paperwidth
  \AM@pageheight=\paperheight
}
\def\AM@setpagedimen{%
  \paperwidth\AM@pagewidth
  \paperheight\AM@pageheight
}
\let\AM@pagesize@boogie\relax
\def\AM@setRotate{\AM@notsupported{Page rotations}}
\def\AM@resetRotate{}
\def\AM@fitpaper@special{\AM@notsupported{Option fitpaper}}
\def\AM@findfile#1{%
  \AM@findfile@i{#1}{eps}%
  \ifx\AM@currentdocname\relax
    \AM@findfile@i{#1}{ps}%
  \fi
  \AM@findfile@ii{#1}%
}
\let\AM@IfFileExists\IfFileExists
\def\AM@linktodoc@special@begin{Links}
\let\AM@linktodoc@special@end\relax
\def\AM@survey@special@begin{\AM@notsupported{Option survey}}
\let\AM@survey@special@end\relax
\def\AM@thread@special@begin{\AM@notsupported{Option thread}}
\let\AM@thread@special@end\relax
\def\AM@reset@view{%
  \def\AM@view{}%
  \def\AM@view@xpos{0}%
  \def\AM@view@ypos{}}
\def\AM@dest@special{\AM@notsupported{Links}}
\def\AM@anchor@special{\AM@notsupported{Links}}
\def\AM@convert@dest#1{}
\let\AM@disable@includegraphics\relax
\@ifundefined{KV@Gin@page}{%
  \define@key{Gin}{page}{%
    \ifnum#1=1 %
    \else
      \PackageError{pdfpages}{%
        Multipage images are not supported by driver dvips%
      }\@ehc
    \fi
  }}{}
\endinput
%%
%% End of file `ppdvips.def'.
