% latin2jk.def
%
% (c) Copyright 1997, 1999, 2000, 2003 J"org Knappen.
% Licence GNU licence Version 2
% see after \endinput for further information
%
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesFile{latin1jk.def}[2003/10/024 latin-2 input encoding file v1.3 (jk)]
%%% \RequirePackage{textcomp}    % text companion symbols (tc fonts)
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\DeclareInputText{"0A0}{\nobreakspace}
\DeclareInputText{"0B0}{\r{}}
\DeclareInputText{"0A1}{\k A}
\DeclareInputText{"0B1}{\k a}
\DeclareInputText{"0A2}{\u{}}
\DeclareInputText{"0B2}{\k\ }
\DeclareInputText{"0A3}{\L}
\DeclareInputText{"0B3}{\l}
\DeclareInputText{"0A4}{\textcurrency}
\DeclareInputText{"0B4}{\@tabacckludge'{}}
\DeclareInputText{"0A5}{\v L}
\DeclareInputText{"0B5}{\v l}
\DeclareInputText{"0A6}{\@tabacckludge'S}
\DeclareInputText{"0B6}{\@tabacckludge's}
\DeclareInputText{"0A7}{\S}
\DeclareInputText{"0B7}{\v{}}
\DeclareInputText{"0A8}{\"{}}
\DeclareInputText{"0B8}{\c\ }
\DeclareInputText{"0A9}{\v S}
\DeclareInputText{"0B9}{\v s}
\DeclareInputText{"0AA}{\c S}
\DeclareInputText{"0BA}{\c s}
\DeclareInputText{"0AB}{\v T}
\DeclareInputText{"0BB}{\v t}
\DeclareInputText{"0AC}{\@tabacckludge'Z}
\DeclareInputText{"0BC}{\@tabacckludge'z}
\DeclareInputText{"0AD}{\-}
\DeclareInputText{"0BD}{\H{}}
\DeclareInputText{"0AE}{\v Z}
\DeclareInputText{"0BE}{\v z}
\DeclareInputText{"0AF}{\.Z}
\DeclareInputText{"0BF}{\.z}
\DeclareInputText{"0C0}{\@tabacckludge'R}
\DeclareInputText{"0D0}{\DJ}
\DeclareInputText{"0C1}{\@tabacckludge'A}
\DeclareInputText{"0D1}{\@tabacckludge'N}
\DeclareInputText{"0C2}{\^A}
\DeclareInputText{"0D2}{\v N}
\DeclareInputText{"0C3}{\u A}
\DeclareInputText{"0D3}{\@tabacckludge'O}
\DeclareInputText{"0C4}{\"A}
\DeclareInputText{"0D4}{\^O}
\DeclareInputText{"0C5}{\@tabacckludge'L}
\DeclareInputText{"0D5}{\H O}
\DeclareInputText{"0C6}{\@tabacckludge'C}
\DeclareInputText{"0D6}{\"O}
\DeclareInputText{"0C7}{\c C}
\DeclareInputText{"0D7}{\texttimes}
\DeclareInputText{"0C8}{\v C}
\DeclareInputText{"0D8}{\v R}
\DeclareInputText{"0C9}{\@tabacckludge'E}
\DeclareInputText{"0D9}{\r U}
\DeclareInputText{"0CA}{\k E}
\DeclareInputText{"0DA}{\@tabacckludge'U}
\DeclareInputText{"0CB}{\"E}
\DeclareInputText{"0DB}{\H U}
\DeclareInputText{"0CC}{\v E}
\DeclareInputText{"0DC}{\"U}
\DeclareInputText{"0CD}{\@tabacckludge'I}
\DeclareInputText{"0DD}{\@tabacckludge'Y}
\DeclareInputText{"0CE}{\^I}
\DeclareInputText{"0DE}{\c T}
\DeclareInputText{"0CF}{\v D}
\DeclareInputText{"0DF}{\ss}
\DeclareInputText{"0E0}{\@tabacckludge'r}
\DeclareInputText{"0F0}{\dj}
\DeclareInputText{"0E1}{\@tabacckludge'a}
\DeclareInputText{"0F1}{\@tabacckludge'n}
\DeclareInputText{"0E2}{\^a}
\DeclareInputText{"0F2}{\v n}
\DeclareInputText{"0E3}{\u a}
\DeclareInputText{"0F3}{\@tabacckludge'o}
\DeclareInputText{"0E4}{\"a}
\DeclareInputText{"0F4}{\^o}
\DeclareInputText{"0E5}{\@tabacckludge'l}
\DeclareInputText{"0F5}{\H o}
\DeclareInputText{"0E6}{\@tabacckludge'c}
\DeclareInputText{"0F6}{\"o}
\DeclareInputText{"0E7}{\c c}
\DeclareInputText{"0F7}{\textdiv}
\DeclareInputText{"0E8}{\v c}
\DeclareInputText{"0F8}{\v r}
\DeclareInputText{"0E9}{\@tabacckludge'e}
\DeclareInputText{"0F9}{\r u}
\DeclareInputText{"0EA}{\k e}
\DeclareInputText{"0FA}{\@tabacckludge'u}
\DeclareInputText{"0EB}{\"e}
\DeclareInputText{"0FB}{\H u}
\DeclareInputText{"0EC}{\v e}
\DeclareInputText{"0FC}{\"u}
\DeclareInputText{"0ED}{\@tabacckludge'\i}
\DeclareInputText{"0FD}{\@tabacckludge'y}
\DeclareInputText{"0EE}{\^\i}
\DeclareInputText{"0FE}{\c t}
\DeclareInputText{"0EF}{\v d}
\DeclareInputText{"0FF}{\.{}}
\endinput
% Usage:
%
% \documentclass{...}
% \usepackage{textcomp} % this package is required!
% \usepackage[latin2jk]{inputenc}
% ...
% \begin{document}
%
% I decided to make \emph{all} characters text, even times and divide, in
% order to make it work in verbatim style environments. A number of control
% sequences refers to the textcomp package of Sebastian Rahtz. The text
% companion fonts are needed to display those characters.
%
% \textcurrency, \texttimes, and \textdiv are defined in 
% the textcomp package using the text companion font (TS1 coding).
%
% Changes:
%
% Version 1.3:
% Get rid of  old definitions requiring tccompat.sty
%
% Author:
%
% J\"org Knappen, Dieselstra{\ss}e 13, 66123 Saarbr\"ucken, Allemagne. 
% Author of the Book: Schnell ans Ziel mit LaTeX2e, Oldenbourg-Verlag
% M\"unchen, 1997, ISBN 3-486-24199-0. 2nd, extended printing 2003.
%
%% End of file `latin2jk.def'.
